#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %{lua_version_nodots} == 51
%define lua_default 1
%endif
%define mod_name luv
%define upver 1.45.0-0
%define fixver %(echo %{upver}|sed 's|-|~|g')
%define libluv_sover 1
%define flavor lua53%{nil}
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif
Version:        %{fixver}
Release:        4.5
Summary:        Bare libuv bindings for lua
License:        Apache-2.0
Group:          Development/Languages/Other
URL:            https://github.com/luvit/%{mod_name}
Source0:        https://github.com/luvit/%{mod_name}/releases/download/%{upver}/%{mod_name}-%{upver}.tar.gz
Patch0:         lua-link.patch
Patch1:         luv-module-install.patch
# PATCH-FIX-UPSTREAM luv-fix-segfault-from-gc.patch gh#luvit/luv#599 mcepl@suse.com
# merged https://github.com/luvit/luv/commit/ff5e90249e08 and
# https://github.com/luvit/luv/commit/ecf3988c0be9
# Also closes gh#luvit/luv#644
Patch2:         luv-fix-segfault-from-gc.patch
BuildRequires:  %{flavor}-compat-5.3
BuildRequires:  %{flavor}-devel
BuildRequires:  %{flavor}-luafilesystem
BuildRequires:  cmake
BuildRequires:  libuv-devel
BuildRequires:  lua-macros
Requires:       %{flavor}
%lua_provides
%if "%{flavor}" == "lua"
ExclusiveArch:  do_not_build
%endif

%description
This library makes libuv available to lua scripts. It was made
for the luvit project but should usable from nearly any lua
project.

The library can be used by multiple threads at once. Each thread
is assumed to load the library from a different lua_State. Luv
will create a unique uv_loop_t for each state. You can't share uv
handles between states/loops.

The best docs currently are the libuv docs themselves. Hopfully
soon we'll have a copy locally tailored for lua.

%if 0%{?lua_default}
%package -n libluv-devel
Summary:        Header files for %{flavor}-%{mod_name}
Group:          Development/Languages/Other
Requires:       libluv%{libluv_sover} = %{version}

%description -n libluv-devel
This subpackage contains header files for developing applications that
want to make use of %{flavor}-%{mod_name}.

%package -n libluv%{libluv_sover}
Summary:        Lua bindings for libluv as a library
Group:          System/Libraries

%description -n libluv%{libluv_sover}
This library makes libuv available to lua scripts. It was made
for the luvit project but should usable from nearly any lua
project.

%post -n libluv%{libluv_sover} -p /sbin/ldconfig
%postun -n libluv%{libluv_sover} -p /sbin/ldconfig
%endif

%prep
echo "Name is %{name}, Flavor is %{flavor}"
%autosetup -p1 -n %{mod_name}-%{upver}

%build
%cmake \
-DWITH_SHARED_LIBUV=ON -DWITH_LUA_ENGINE=Lua \
-DLUA_BUILD_TYPE=System -DMODULE_INSTALL_LIB_DIR=%{lua_archdir} \
-DSHAREDLIBS_INSTALL_LIB_DIR=%{_libdir} -DBUILD_SHARED_LIBS=OFF \
-DLUA_COMPAT53_DIR="%{lua_incdir}" \
%{?lua_default:-DBUILD_SHARED_LIBS=ON}
%cmake_build

%install
%cmake_install

%files
%license LICENSE.txt
%doc *.md
%{lua_archdir}/luv.so

%if 0%{?lua_default}
%files -n libluv-devel
%license LICENSE.txt
%{_includedir}/%{mod_name}
%{_libdir}/libluv.so
%{_libdir}/pkgconfig/*.pc

%files -n libluv%{libluv_sover}
%{_libdir}/libluv.so.*
%endif

%changelog
* Mon Dec  4 2023 Noah Dörr <archecraft1@gmail.com>
- Update to version 1.45.0-0:
  * Add access(2) constants to the constants table
  * thread_setaffinity: Allow affinity param to have a length less
    than cpumask_size()
  * avoid thread be released before it done
  * fix thread arguments limit
  * fix segfault in luv_check_handle/luv_check_stream
  * add uv.errno table contains all uv errno value
  * segfault on new_thread and worker.queue
  * segfault on luv_check_handle
  * uv.spawn example code in docs is broken
  * pthread_create possible leak
- Update to version 1.44.2-1:
  * Removed output to stderr from poll callback
- Update to version 1.44.2-0:
  * Adds new function uv.available_parallelism
  * uv.os_get_passwd: Better handling of gid/uid
  * uv.fs_opendir and friends: Fix race condition when uv_dir_t
    pointer doesn't change between allocations
  * Fix leak from fs_scandir whenever it wasn't fully iterated via
    fs_scandir_next
  * Fix two possible fs_scandir segfaults
- Add luv-fix-segfault-from-gc.patch fixing segfaults
  (gh#luvit/luv#599 and gh#luvit/luv#644)
* Sun Feb 13 2022 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.43.0-0:
  * Only new function is uv_ip_name which luv does not provide
    a binding for
  * Change the call to acquire_vm_cb() in luv.new_therad() to
    be made before the thread is created in luv_new_thread()
* Wed Nov 17 2021 Callum Farmer <gmbr3@opensuse.org>
- Use system compat53 again
* Wed Nov 17 2021 Callum Farmer <gmbr3@opensuse.org>
- Change default version to Lua 5.1
* Tue Nov 16 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.42.0-1:
  * Use uv_handle_size/uv_req_size instead of sizeof
  * LuaJIT: add missing LJ_ENDIAN and LJ_NO_UNWIND checks for DASM
    [this fixes building on aarch64]
- Fix shared library build
- Clean spec file
- Add lua-link.patch: must link with -llua
- Add luv-module-install.patch: fix module install path
* Sat Apr 24 2021 Matej Cepl <mcepl@suse.com>
- Use correct upstream tarball
* Sat Apr 24 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.41.0:
  * Fix build with Lua 5.4
  * Updated Libuv to 1.40.0
  * Fix garbage collection-related memory bug with threads
  * Make symlink/copyfile bindings more user-friendly
- Tests and examples no longer included in tarball
- Removed skip-failing-test.patch: no longer applicable
* Fri Feb 26 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix placement of %%lua_provides
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target and fix problems with
  compatibility with it.
* Sun Apr 12 2020 Matej Cepl <mcepl@suse.com>
- We don't need to define macros, when lua-macros is finally
  fixed.
* Sat Apr 11 2020 Matej Cepl <mcepl@suse.com>
- Better version of the patch, based upon the upstream advice.
* Wed Apr  8 2020 Matej Cepl <mcepl@suse.com>
- Add skip-failing-test.patch to failing test on Leap 15
  (gh#luvit/luv#473)
* Thu Sep 19 2019 Matej Cepl <mcepl@suse.com>
- Update to 1.30.1-1: mostly bugfixes. Full log is only
  https://github.com/luvit/luv/commits/master
* Fri Aug  9 2019 Matej Cepl <mcepl@suse.com>
- devel package doesn’t need luv%%{sover} package, when public
  library is not built.
* Sat Aug  3 2019 Matej Cepl <mcepl@suse.com>
- Remove public shared library again.
* Sun Jul  7 2019 Matej Cepl <mcepl@suse.com>
- Make system buildable on Fedora/CentOS as well.
* Thu Jul  4 2019 Matej Cepl <mcepl@suse.com>
- Provide public shared library again.
* Wed Jul  3 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.30.0-0:
  - Reduce latency and speed up testing
  - improve thread and threadpool
  - more flexible callback support
  - Simplify callback in thread and threadpool
  - support custom/external event callback
  - Speed up by reduce regristry table queries
  - Allow dns tests that require an internet connection to fail when offline
  - CMake: use REQUIRED with LuaJIT/Lua
  - cmake: handle luajit 2.1 (#343)
* Thu Jun 13 2019 Matej Cepl <mcepl@suse.com>
- Initial packaging
